import { computed, h, defineComponent } from 'vue';
import { kebabCase } from 'lodash-es';
import { useConfig, useTheme } from '../../_mixins';
import { elementLight } from '../styles';
const elementProps = Object.assign(Object.assign({}, useTheme.props), { tag: {
        type: String,
        default: 'div'
    }, abstract: Boolean });
export default defineComponent({
    name: 'Element',
    alias: ['El'],
    props: elementProps,
    setup(props) {
        const { mergedClsPrefixRef } = useConfig(props);
        const themeRef = useTheme('Element', 'Element', undefined, elementLight, props, mergedClsPrefixRef);
        return {
            mergedClsPrefix: mergedClsPrefixRef,
            mergedTheme: themeRef,
            cssVars: computed(() => {
                const { common } = themeRef.value;
                return Object.keys(common).reduce((prevValue, key) => {
                    prevValue[`--${kebabCase(key)}`] = common[key];
                    return prevValue;
                }, {});
            })
        };
    },
    render() {
        var _a, _b;
        const { $slots, abstract, mergedTheme: { common } } = this;
        if (abstract) {
            return (_a = $slots.default) === null || _a === void 0 ? void 0 : _a.call($slots, {
                themeVars: common
            });
        }
        const { tag, mergedClsPrefix, cssVars } = this;
        return h(tag, {
            class: `${mergedClsPrefix}-element`,
            style: cssVars
        }, (((_b = $slots.default) === null || _b === void 0 ? void 0 : _b.call($slots, {
            themeVars: common
        })) || null));
    }
});
